pub struct Raw {
pub id: u8,
}Expand description
Raw axis.
Usually you can get input from mouse using three axes:
id = 0for moves alongXaxis.id = 1for moves alongYaxis.id = 2for mouse wheel moves.
However, these ids depend on hardware and may vary on different machines.
Fields
id: u8Axis id.